import {NgModule} from '@angular/core'
import {Routes, RouterModule} from '@angular/router'
import {CatalogComponent} from './pages/catalog/catalog.component'
import {AdministrationComponent} from './pages/administration/administration.component'
import {MiscComponent} from './pages/others/misc.component'
import {CreConfigEditor} from './modules/configuration/config-editor'
import {routes as routesConst} from './routes'

const routes: Routes = [{
  path: routesConst.recipes.route,
  loadChildren: () => import('./modules/recipes/recipes.module').then(m => m.RecipesModule)
}, {
  path: routesConst.accounts.route,
  loadChildren: () => import('./modules/accounts/accounts.module').then(m => m.AccountsModule)
}, {
  path: routesConst.catalog.route,
  component: CatalogComponent,
  children: [{
    path: routesConst.catalog.children.materialTypes.simpleRoute,
    loadChildren: () => import('./modules/material-type/material-type.module').then(m => m.MaterialTypeModule),
  }, {
    path: routesConst.catalog.children.materials.simpleRoute,
    loadChildren: () => import('./modules/material/material.module').then(m => m.MaterialModule)
  }, {
    path: routesConst.catalog.children.companies.simpleRoute,
    loadChildren: () => import('./modules/company/company.module').then(m => m.CompanyModule)
  }, {
    path: '',
    pathMatch: 'full',
    redirectTo: routesConst.catalog.children.materials.simpleRoute
  }]
}, {
  path: routesConst.administration.route,
  component: AdministrationComponent,
  children: [
    {
      path: routesConst.administration.children.users.simpleRoute,
      loadChildren: () => import('./modules/users/user.module').then(m => m.UserModule)
    }, {
      path: routesConst.administration.children.groups.simpleRoute,
      loadChildren: () => import('./modules/groups/group.module').then(m => m.GroupModule)
    }, {
      path: routesConst.administration.children.groupTokens.simpleRoute,
      loadChildren: () => import('./modules/groupTokens/group-tokens.module').then(m => m.GroupTokensModule)
    }, {
      path: routesConst.administration.children.configurations.simpleRoute,
      loadChildren: () => import('./modules/configuration/config.module').then(m => m.ConfigModule),
      component: CreConfigEditor
    }, {
      path: '',
      pathMatch: 'full',
      redirectTo: routesConst.administration.children.users.simpleRoute
    }
  ]
}, {
  path: routesConst.misc.route,
  component: MiscComponent,
  children: [{
    path: routesConst.misc.children.touchUpKits.simpleRoute,
    loadChildren: () => import('./modules/touch-up-kit/touch-up-kit.module').then(m => m.TouchUpKitModule)
  }, {
    path: '',
    pathMatch: 'full',
    redirectTo: routesConst.misc.children.touchUpKits.simpleRoute
  }]
}]

@NgModule({
  imports: [RouterModule.forRoot(routes)],
  exports: [RouterModule]
})
export class AppRoutingModule {
}
