import {Injectable} from "@angular/core";
import {ApiService} from "../../shared/service/api.service";
import {Observable} from "rxjs";
import {GroupToken} from "../../shared/model/account.model";

@Injectable({
  providedIn: "root"
})
export class GroupTokenService {
  constructor(
    private api: ApiService
  ) {
  }

  get all(): Observable<GroupToken[]> {
    return this.api.get<GroupToken[]>('/account/group/token')
  }

  get current(): Observable<GroupToken | null> {
    return this.api.get<GroupToken | null>('/account/group/token/current')
  }

  save(name: string, groupId: number): Observable<GroupToken> {
    return this.api.post<GroupToken>('/account/group/token', {name, groupId})
  }

  toggle(token: GroupToken): Observable<void> {
    return token.enabled ?
      this.api.put<void>(`/account/group/token/${token.id}/disable`) :
      this.api.put<void>(`/account/group/token/${token.id}/enable`)
  }

  delete(id: string): Observable<void> {
    return this.api.delete<void>(`/account/group/token/${id}`)
  }
}
