import {Injectable} from '@angular/core'
import {LoginDto} from './model/account.model'
import {Subject} from 'rxjs'
import {Title} from '@angular/platform-browser'

@Injectable({
  providedIn: 'root'
})
export class AppState {
  private readonly KEY_AUTHENTICATED_USER = 'authenticated-user'
  private readonly KEY_GROUP_USER = 'authenticated-user-group'

  authenticatedUser$ = new Subject<AuthenticationEvent>()
  serverOnline$ = new Subject<boolean>()

  constructor(
    private titleService: Title
  ) {
  }

  authenticateUser(user: LoginDto, isGroup: boolean) {
    this.setAuthenticatedUser(user, isGroup)
  }

  resetAuthenticatedUser() {
    this.removeAuthenticatedUser()
  }

  set isServerOnline(isOnline: boolean) {
    if (!isOnline) {
      this.removeAuthenticatedUser()
    }
    this.serverOnline$.next(isOnline)
  }

  get isAuthenticated(): boolean {
    return !!this.authenticatedUser
  }

  get authenticatedUser(): LoginDto {
    const userString = sessionStorage.getItem(this.KEY_AUTHENTICATED_USER)
    return userString ? JSON.parse(userString) : null
  }

  get isGroupUserAuthenticated(): boolean {
    return sessionStorage.getItem(this.KEY_GROUP_USER) === 'true'
  }

  private setAuthenticatedUser(login: LoginDto, isGroup: boolean) {
    sessionStorage.setItem(this.KEY_AUTHENTICATED_USER, JSON.stringify(login))
    sessionStorage.setItem(this.KEY_GROUP_USER, JSON.stringify(isGroup))
    this.authenticatedUser$.next({
      authenticatedUser: login,
      isGroup
    })
  }

  private removeAuthenticatedUser() {
    sessionStorage.removeItem(this.KEY_AUTHENTICATED_USER)
    sessionStorage.removeItem(this.KEY_GROUP_USER)
    this.authenticatedUser$.next({
      authenticatedUser: null,
      isGroup: false
    })
  }

  set title(value: string) {
    this.titleService.setTitle(`CRE: ${value}`)
  }
}

export interface AuthenticationEvent {
  authenticatedUser: LoginDto | null
  isGroup: boolean
}
