import {Component, OnDestroy, OnInit} from '@angular/core'
import {AppState, AuthenticationEvent} from '../../app-state'
import {LoginDto} from '../../model/account.model'
import {Subject} from 'rxjs'
import {takeUntil} from 'rxjs/operators'
import {UrlUtils} from '../../utils/url.utils'
import {ActivatedRoute, Router} from '@angular/router'
import {routes} from "../../../../routes";

@Component({
  selector: 'cre-user-menu',
  templateUrl: './user-menu.component.html',
  styleUrls: ['./user-menu.component.sass']
})
export class UserMenuComponent implements OnInit, OnDestroy {
  user: LoginDto = null
  groupUser: boolean = false

  showMenu = false

  private destroy$ = new Subject<boolean>()
  private urlUtils: UrlUtils

  constructor(
    private appState: AppState,
    private router: Router,
    private activatedRoute: ActivatedRoute
  ) {
    this.urlUtils = new UrlUtils(activatedRoute, router)
  }

  ngOnInit(): void {
    this.setInitialAuthenticationState()

    this.appState.authenticatedUser$
      .pipe(takeUntil(this.destroy$))
      .subscribe({
        next: event => this.processAuthenticationEvent(event)
      })
  }

  ngOnDestroy(): void {
    this.destroy$.next(true)
    this.destroy$.complete()
  }

  openLogin() {
    this.urlUtils.navigateTo(routes.accounts.route + '/login')
    this.hideMenu()
  }

  openLogout() {
    this.urlUtils.navigateTo(routes.accounts.route + '/logout')
    this.hideMenu()
  }

  private setInitialAuthenticationState() {
    this.user = this.appState.authenticatedUser
    this.groupUser = this.appState.isGroupUserAuthenticated
  }

  private processAuthenticationEvent(event: AuthenticationEvent) {
    this.user = event.authenticatedUser
    this.groupUser = event.isGroup
  }

  private hideMenu() {
    this.showMenu = false
  }
}
